==> echosms-0.1.3-py3-none-any.whl: echosms/referencemodels.py <==
"""Reference model parameters."""

from pathlib import Path
import toml  # Could use standard library tomllib once python >=3.11
import pandas as pd
pd.options.mode.copy_on_write = True


class ReferenceModels:
    """Provide access to reference scattering model parameters.

    Attributes
    ----------
    definitions : dict
        A dict representation of the ``target definitions.toml`` file.

    Raises
    ------
    KeyError
        If the ``target definitions.toml`` file has multiple target entries with the same name.
    """

    def __init__(self):
        self.defs_filename = Path(__file__).parent/Path('resources')/Path('target definitions.toml')

        self.definitions = []

        with open(self.defs_filename, 'r') as f:
            self.definitions = toml.load(f)

        # Flag duplicate target names
        pda = pd.Series(self.names())
        duplicates = list(pda[pda.duplicated()])
        if duplicates:
            raise KeyError(f'The "{self.defs_filename.name}" file has multiple targets '
                           f'with the same name: '+', '.join(duplicates))

        # Substitute parameters names in the target section by the values of those
        # parameters.
        for t in self.definitions['target']:
            for k, v in t.items():
                try:
                    t[k] = self.definitions['parameters'][v]
                except (KeyError, TypeError):
                    pass

    def names(self):
        """Names of all model definitions.

        Returns
        -------
        : iterable of str
            All model names in the ``target definitions.toml`` file.
        """
        return [n['name'] for n in self.definitions['target']]

    def specification(self, name):
        """Model defintions for a particular model.

        Parameters
        ----------
        name : str
            The name of a model in the ``target definitions.toml`` file.

        Returns
        -------
        : dict
            The model definitions for the requested model or an empty set if no model
            with that name.
        """
        s = [t for t in self.definitions['target'] if t['name'] == name]
        if not s:
            return s

        return s[0]

    def parameters(self, name):
        """Model parameters for a particular model.

        Model parameters are a subset of the model specification where the metadata items have
        been removed.

        Parameters
        ----------
        name : str
            The name of a model in the ``target definitions.toml`` file.

        Returns
        -------
        : dict
            The model parameters for the requested model or an empty set if no model with that name.

        """
        s = self.specification(name)

        if not s:
            return []

        # Remove the entries that are not parameters
        p = s.copy()
        del p['name']
        del p['shape']
        del p['description']
        del p['source']
        del p['benchmark_model']
        return p

==> echosms-0.1.6-py3-none-any.whl: echosms/referencemodels.py <==
"""Reference model parameters."""

from pathlib import Path
import sys
if sys.version_info >= (3, 11):
    import tomllib
else:
    import tomli as tomllib
import pandas as pd
pd.options.mode.copy_on_write = True


class ReferenceModels:
    """Provide access to reference scattering model parameters.

    Attributes
    ----------
    definitions : dict
        A dict representation of the ``target definitions.toml`` file.

    Raises
    ------
    TOMLDecodeError
        If the ``target definitions.toml`` file is not valid TOML.
    KeyError
        If the ``target definitions.toml`` file has multiple target entries with the same name.
    """

    def __init__(self):
        self.defs_filename = Path(__file__).parent/Path('resources')/Path('target definitions.toml')

        self.definitions = []

        with open(self.defs_filename, 'rb') as f:
            try:
                self.definitions = tomllib.load(f)
            except tomllib.TOMLDecodeError as e:
                raise Exception(f'Error while parsing file "{self.defs_filename.name}"') from e

        # Flag duplicate target names
        pda = pd.Series(self.names())
        duplicates = list(pda[pda.duplicated()])
        if duplicates:
            raise KeyError(f'The "{self.defs_filename.name}" file has multiple targets '
                           f'with the same name: '+', '.join(duplicates))

        # Substitute parameters names in the target section by the values of those
        # parameters.
        for t in self.definitions['target']:
            for k, v in t.items():
                try:
                    t[k] = self.definitions['parameters'][v]
                except (KeyError, TypeError):
                    pass

    def names(self):
        """Names of all model definitions.

        Returns
        -------
        : iterable of str
            All model names in the ``target definitions.toml`` file.
        """
        return [n['name'] for n in self.definitions['target']]

    def specification(self, name):
        """Model defintions for a particular model.

        Parameters
        ----------
        name : str
            The name of a model in the ``target definitions.toml`` file.

        Returns
        -------
        : dict
            The model definitions for the requested model or an empty set if no model
            with that name.
        """
        s = [t for t in self.definitions['target'] if t['name'] == name]
        if not s:
            return s

        return s[0]

    def parameters(self, name):
        """Model parameters for a particular model.

        Model parameters are a subset of the model specification where the metadata items have
        been removed.

        Parameters
        ----------
        name : str
            The name of a model in the ``target definitions.toml`` file.

        Returns
        -------
        : dict
            The model parameters for the requested model or an empty set if no model with that name.

        """
        s = self.specification(name)

        if not s:
            return []

        # Remove the entries that are not parameters
        p = s.copy()
        {}
        [p.pop(k, None) for k in ['name', 'shape', 'description', 'source', 'benchmark_model']]
        return p
